@@ -4,8 +4,8 @@ use std::collections::HashSet;
 use std::io::BufRead;
 
 // Create clap subcommand arguments
-pub fn make_subcommand<'a>() -> App<'a> {
-    App::new("restrict")
+pub fn make_subcommand<'a>() -> Command<'a> {
+    Command::new("restrict")
         .about("Restrict overlaps to known pairs")
         .arg(
             Arg::new("infile")
